@@ -2,16 +2,15 @@
 
 use strict;
 use warnings;
+use Log::Log4perl qw( :easy );
+
+Log::Log4perl->easy_init( $INFO );
 
 use lib '../lib';
 
-use Log::Log4perl qw( :easy );
-
 use Autocache qw( autocache );
 
-Log::Log4perl->easy_init( $DEBUG );
-
-Autocache->initialise( filename => './refresher.conf', logger => get_logger() );
+Autocache->initialise( filename => './refresher.conf' );
 
 autocache 'cached_time';
 
