@@ -3,20 +3,23 @@ package Autocache;
 use strict;
 use warnings;
 
-our $VERSION = '0.003_003';
+our $VERSION = '0.001';
 $VERSION = eval $VERSION;
 
-use Autocache::Config;
-use Autocache::Request;
-use Autocache::Strategy::Store::Memory;
-use Autocache::WorkQueue;
-use Autocache::Logger qw(get_logger);
 use Carp;
+use Data::Dumper;
+use Log::Log4perl qw( get_logger );
+
+use Autocache::Config;
+use Autocache::Store::Memory;
+use Autocache::Strategy::Simple;
+use Autocache::WorkQueue;
 
 require Exporter;
 
 our @ISA = qw( Exporter );
-our @EXPORT = qw( autocache );
+our @EXPORT = ();
+our @EXPORT_OK = qw( autocache );
 
 my $SINGLETON;
 
@@ -41,9 +44,6 @@ sub initialise
     my $class = shift;
     $SINGLETON = $class->new( @_ );
     $SINGLETON->configure;
-    my %args = @_;
-    Autocache::Logger->initialise(logger => $args{logger})
-        if $args{logger};
 }
 
 sub new
@@ -53,6 +53,7 @@ sub new
     my $self =
         {
             config => $config,
+            store => {},
             strategy => {},
             default_strategy => undef,
             work_queue => undef,
@@ -64,6 +65,25 @@ sub new
 sub configure
 {
     my ($self) = @_;
+    
+    foreach my $node ( $self->{config}->get_node( 'store' )->children )
+    {
+        my $name = $node->name;
+        my $package = $node->value;
+        _use_package( $package );
+
+        my $store;
+
+        eval
+        {
+            $store = $package->new( $node );
+        };
+        if( $@ )
+        {
+            confess "cannot create store $name using package $package - $@";
+        }
+        $self->{store}{$node->name} = $store;
+    }
 
     foreach my $node ( $self->{config}->get_node( 'strategy' )->children )
     {
@@ -86,17 +106,39 @@ sub configure
 
     $self->configure_functions( $self->{config}->get_node( 'fn' ) );
 
+#    if( $self->{config}->get_node( 'default_store' ) )
+#    {
+#        $self->{default_store} = $self->get_store(
+#            $self->{config}->get_node( 'default_store' )->value );
+#    }
+
     if( $self->{config}->node_exists( 'default_strategy' ) )
     {
         $self->{default_strategy} = $self->get_strategy(
             $self->{config}->get_node( 'default_strategy' )->value );
     }
+
+    my $stats = $self->{config}->get_node( 'stats' );
+    if( $stats->node_exists( 'enable' ) )
+    {
+        $self->{enable_stats} = $stats->get_node( 'enable' )->value;
+    }
+    
+    if( exists $ENV{AUTOCACHE_STATS} )
+    {
+        $self->{enable_stats} = $ENV{AUTOCACHE_STATS};
+    }
+    
+    if( $stats->node_exists( 'dump_on_exit' ) )
+    {
+        $self->{dump_stats} = $stats->get_node( 'dump_on_exit' )->value;
+    }
 }
 
 sub configure_functions
 {
     my ($self,$node,$namespace) = @_;
-
+    
     $namespace ||= '';
 
     if( $node->value )
@@ -138,13 +180,13 @@ sub _cache_function
     get_logger()->debug( "cache : $r / $g"  );
 
     no strict 'refs';
-
+    
     # get generator routine ref
     my $gsub = *{$r}{CODE};
 
     # see if we have a normaliser
     my $gsub_norm = *{$n}{CODE};
-
+    
     unless( defined $gsub_norm )
     {
         get_logger()->debug( "no normaliser, using default" );
@@ -184,7 +226,7 @@ sub get_strategy_for_fn
 {
     my ($self,$name) = @_;
     get_logger()->debug( "get_strategy_for_fn '$name'" );
-
+    
     return $self->get_default_strategy()
         unless exists $self->{fn}{$name}{strategy};
 
@@ -200,17 +242,38 @@ sub get_strategy
     return $self->{strategy}{$name};
 }
 
+sub get_store
+{
+    my ($self,$name) = @_;
+    get_logger()->debug( "get_store '$name'" );
+    confess "cannot find store $name"
+        unless $self->{store}{$name};
+    return $self->{store}{$name};
+}
+
 sub get_default_strategy
 {
     my ($self) = @_;
     get_logger()->debug( "get_default_strategy" );
     unless( $self->{default_strategy} )
     {
-        $self->{default_strategy} = Autocache::Strategy::Store::Memory->new;
+        $self->{default_strategy} = Autocache::Strategy::Simple->new(
+            store => $self->get_default_store() );
     }
     return $self->{default_strategy};
 }
 
+sub get_default_store
+{
+    my ($self) = @_;
+    get_logger()->debug( "get_default_store" );
+    unless( $self->{default_store} )
+    {
+        $self->{default_store} = Autocache::Store::Memory->new;
+    }
+    return $self->{default_store};
+}
+
 sub get_default_normaliser
 {
     my ($self) = @_;
@@ -227,26 +290,20 @@ sub _generate_cached_fn
     {
         get_logger()->debug( "CACHE $name" );
         return unless defined wantarray;
-        my $context = wantarray ? 'L' : 'S';
+        my $return_type = wantarray ? 'L' : 'S';
 
-        get_logger()->debug( "calling context: $context" );
-
-        my $request = Autocache::Request->new(
-            name => $name,
-            normaliser => $normaliser,
-            generator => $coderef,
-            args => \@_,
-            context => $context,
-        );
+        get_logger()->debug( "return type: $return_type" );
 
         my $strategy = $self->get_strategy_for_fn( $name );
 
-        my $rec = $strategy->get( $request );
+        my $rec = $strategy->get_cache_record(
+            $name, $normaliser, $coderef, \@_, $return_type );
 
         unless( $rec )
         {
-            $rec = $strategy->create( $request );
-            $strategy->set( $request, $rec );
+            $rec = $strategy->create_cache_record(
+                $name, $normaliser, $coderef, \@_, $return_type );
+            $strategy->set_cache_record( $rec );
         }
 
         my $value = $rec->value;
@@ -264,7 +321,7 @@ sub _default_normaliser
 sub _use_package
 {
     my ($name) = @_;
-    get_logger()->debug( "use $name" );
+    get_logger()->debug( "use $name" );    
     eval "use $name";
     if( $@ )
     {
@@ -272,6 +329,65 @@ sub _use_package
     }
 }
 
+sub _dump_stats
+{
+    my ($self) = @_;
+    print STDERR "AUTOCACHE STATS\n";
+    foreach my $name ( keys %{$self->{strategy}} )
+    {
+        print STDERR "STRATEGY: $name\n";
+
+        my $strategy = $self->{strategy}{$name};
+
+#        print STDERR "STRAT: ", Dumper( $strategy ), "\n";
+
+        next unless $strategy;
+    
+        my $stats = $strategy->get_statistics();
+
+        if( $stats->{total} > 0 )
+        {
+            printf STDERR "hit  : %8d / %3.2f%%\n",
+                $stats->{hit},
+                ( $stats->{hit} / $stats->{total} ) * 100;
+            printf STDERR "miss : %8d / %3.2f%%\n",
+                $stats->{miss},
+                ( $stats->{miss} / $stats->{total} ) * 100;
+            printf STDERR "total: %d\n", $stats->{total};
+        }
+        else
+        {
+            print STDERR "no statistics available\n";
+        }
+        print STDERR "\n";
+    }
+
+    foreach my $strategy ( values %{$self->{strategy}} )
+    {
+#        print STDERR "STRAT: ", Dumper( $strategy ), "\n";
+
+        next unless $strategy;
+    
+        my $stats = $strategy->get_statistics();
+
+        if( $stats->{total} > 0 )
+        {
+#            printf STDERR "hit  : %-8d / %-3.2f\n",
+#                ( $stats->{hit} / $stats->{total} ) * 100;
+#            printf STDERR "miss : %-8d / %-3.2f\n",
+#                ( $stats->{miss} / $stats->{total} ) * 100;
+#            printf STDERR "total: %d\n", $stats->{total};
+        }
+        else
+        {
+#            print STDERR "no statistics available\n";
+        }
+#        print STDERR "\n";
+    }
+
+    print STDERR "AUTOCACHE STATS DONE\n";
+}
+
 1;
 
 __END__
@@ -311,12 +427,15 @@ In addition to this though Autocache allows you to specify in great detail
 how and where function results get cached.
 
 The module uses IoC/dependency injection from a configuration file to setup
-a number Strategies. These are the basic building blocks used to determine
-how things get cached.
+a number of Stores and Strategies. These are the basic building blocks used
+to determine how things get cached.
 
 Strategies determine how a cached value should be validated, refreshed, and
 even whether or not the value should be stored at all.
 
+Stores provide the actual storage for values and also specify how values get
+evicted from stores, if at all.
+
 The goal here is to make it stupidly simple to start to cache certain
 functions, and change where and how those values get cached if you find
 they're in the wrong place.
@@ -336,7 +455,7 @@ A pure function being one;
 
 =item
 
-whose value depends soley on the parameters passed to the function and no other global information, state or input from IO or external devices.
+whose value depends soley on the parameters passed to the function and no other global information, state or input from IO or external devices. 
 
 =item
 
@@ -424,7 +543,7 @@ parameters named 'a', 'b', 'c' and 'd' then the following calls are
 equivalent but autocache can't tell that.
 
     fn( 'a', 3, 'd', 4 );
-
+    
     fn( 'd', 4, 'a', 3 )
 
 To overcome this you can provide a normalisation function that takes the
@@ -477,18 +596,20 @@ the same value is returned in either scalr or list context.
 
 =head1 ARCHITECTURE
 
-Autocache initially split up the process of caching into generating the values and
-storing the values.  This has since been unified under the banner of 'strategies'.
-There is a 'Store' namespace in 'Strategy', intended to represent strategies
-that involve storage.
+Autocache splits up the process of caching into generating the values and
+storing the values.
 
-Strategies may be chained.  Some examples of Strategies are CostBased, Refresh,
-Store::Memory and Store::Memcached.
+Values are generated using Strategies, which may be chained. Some examples
+of Strategies are Simple, Refresh and CostBased.
 
-The API for Strategies is not yet completely fixed but you should be able to quite
-easily take one of those that already exists and modify it to suit your needs. The
-configuration syntax allows you to use any custom classes you like as long as they
-can accept the way we perform IoC (sub-optimal right now).
+Values are stored using Stores. Some examples of Stores are UnboundedMemory,
+BoundedMemoryLRU and Memcached.
+
+The API for both Strategies and Stores is not yet completely fixed but you
+should be able to quite easily take one of those that already exists and
+modify it to suit your needs. The configuration syntax allows you to use any
+custom classes you like as long as they can accept the way we perform IoC
+(sub-optimal right now).
 
 =head1 TODO
 
