@@ -3,7 +3,7 @@ package Autocache::Record;
 use strict;
 use warnings;
 
-use Autocache::Logger qw(get_logger);
+use Log::Log4perl qw( get_logger );
 
 our $AUTOLOAD;
 
