@@ -6,7 +6,7 @@ extends 'Autocache::Strategy';
 
 use Autocache;
 use Carp;
-###l4p use Log::Log4perl qw( get_logger );
+use Log::Log4perl qw( get_logger );
 use Scalar::Util qw( weaken );
 
 #
@@ -43,78 +43,62 @@ has 'work_queue' => (
     lazy_build => 1,
 );
 
-#
-# create REQ
-#
-sub create
+sub create_cache_record
 {
-    my ($self,$req) = @_;
-###l4p     get_logger()->debug( "create" );
-    return $self->base_strategy->create( $req );
+    my ($self,$name,$normaliser,$coderef,$args,$return_type) = @_;
+    get_logger()->debug( "create_cache_record" );
+    return $self->base_strategy->create_cache_record(
+        $name,$normaliser,$coderef,$args,$return_type);
 }
 
-sub get
+sub get_cache_record
 {
-    my ($self,$req) = @_;
-###l4p     get_logger()->debug( "get" );
-    my $rec = $self->base_strategy->get( $req );
-
+    my ($self,$name,$normaliser,$coderef,$args,$return_type) = @_;
+    get_logger()->debug( "get_cache_record" );
+    my $rec = $self->base_strategy->get_cache_record(
+        $name, $normaliser, $coderef, $args, $return_type );    
+    
 
     #
     # TODO - add min refresh time to stop cache stampede for shared caches
     #
     if( $rec and ( $rec->age > $self->refresh_age ) )
     {
-###l4p         get_logger()->debug( "record age  : " . $rec->age );
-###l4p         get_logger()->debug( "refresh age : " . $self->refresh_age );
+        get_logger()->debug( "record age  : " . $rec->age );
+        get_logger()->debug( "refresh age : " . $self->refresh_age );
 
-        $self->work_queue->push( $self->_refresh_task( $req, $rec ) );
+        $self->work_queue->push(
+            $self->_refresh_task(
+                $name, $normaliser, $coderef, $args, $return_type, $rec ) );
     }
 
-    return $rec;
+    return $rec;    
 }
 
-#
-# REQ REC
-#
-sub set
+sub set_cache_record
 {
-    my ($self,$req,$rec) = @_;
-###l4p     get_logger()->debug( "set " . $rec->name );
-    return $self->base_strategy->set( $req, $rec );
+    my ($self,$rec) = @_;
+    get_logger()->debug( "set_cache_record " . $rec->name );
+    return $self->base_strategy->set_cache_record( $rec );    
 }
 
 sub _refresh_task
 {
-    my ($self,$req,$rec) = @_;
+    my ($self,$name,$normaliser,$coderef,$args,$return_type,$rec) = @_;
 
-###l4p     get_logger()->debug( "_refresh_task " . $name );
+    get_logger()->debug( "_refresh_task " . $name );
 
     weaken $self;
-
+        
     return sub
     {
-###l4p         get_logger()->debug( "refreshing record: " . $rec->to_string );
-        my $fresh_rec = $self->create( $req );
-        $self->set( $fresh_rec );
+        get_logger()->debug( "refreshing record: " . $rec->to_string );
+        my $fresh_rec = $self->create_cache_record(
+            $name, $normaliser, $coderef, $args, $return_type );
+        $self->set_cache_record( $fresh_rec );
     };
 }
 
-#
-# delete KEY
-#
-sub delete
-{
-    my ($self,$key) = @_;
-    return $self->base_strategy->delete( $key );
-}
-
-sub clear
-{
-    my ($self) = @_;
-    return $self->base_strategy->clear;
-}
-
 sub _build_base_strategy
 {
     return Autocache->singleton->get_default_strategy();
@@ -130,7 +114,7 @@ around BUILDARGS => sub
     my $orig = shift;
     my $class = shift;
 
-###l4p     get_logger()->debug( __PACKAGE__ . " - BUILDARGS" );
+    get_logger()->debug( __PACKAGE__ . " - BUILDARGS" );
 
     if( ref $_[0] )
     {
@@ -140,13 +124,13 @@ around BUILDARGS => sub
 
         if( $node = $config->get_node( 'base_strategy' ) )
         {
-###l4p             get_logger()->debug( "base strategy node found" );
+            get_logger()->debug( "base strategy node found" );
             $args{base_strategy} = Autocache->singleton->get_strategy( $node->value );
         }
-
+        
         if( $node = $config->get_node( 'refresh_age' ) )
         {
-###l4p             get_logger()->debug( "refresh age node found" );
+            get_logger()->debug( "refresh age node found" );
             $args{refresh_age} = $node->value;
         }
 
