@@ -5,7 +5,7 @@ use Any::Moose;
 extends 'Autocache::Strategy';
 
 use Autocache;
-use Autocache::Logger qw(get_logger);
+use Log::Log4perl qw( get_logger );
 
 #
 # base_strategy : underlying strategy that handles storage and expiry -
@@ -26,26 +26,21 @@ has 'statistics' => (
     lazy_build => 1,
 );
 
-#
-# create REQ
-#
-sub create
+sub create_cache_record
 {
-    my ($self,$req) = @_;
-    get_logger()->debug( "create" );
+    my ($self,$name,$normaliser,$coderef,$args,$return_type) = @_;
+    get_logger()->debug( "create_cache_record" );
     ++$self->statistics->{create};
-    return $self->base_strategy->create( $req );
+    return $self->base_strategy->create_cache_record(
+        $name,$normaliser,$coderef,$args,$return_type);
 }
 
-#
-# get REQ
-#
-sub get
+sub get_cache_record
 {
-    my ($self,$req) = @_;
-    get_logger()->debug( "get" );
-    my $rec = $self->base_strategy->get(
-        $req );
+    my ($self,$name,$normaliser,$coderef,$args,$return_type) = @_;
+    get_logger()->debug( "get_cache_record" );
+    my $rec = $self->base_strategy->get_cache_record(
+        $name, $normaliser, $coderef, $args, $return_type );    
     if( $rec )
     {
         ++$self->statistics->{hit};
@@ -58,29 +53,11 @@ sub get
     return $rec;
 }
 
-#
-# REQ REC
-#
-sub set
+sub set_cache_record
 {
-    my ($self,$req,$rec) = @_;
-    get_logger()->debug( "set " . $rec->name );
-    return $self->base_strategy->set( $req, $rec );
-}
-
-#
-# delete KEY
-#
-sub delete
-{
-    my ($self,$key) = @_;
-    return $self->base_strategy->delete( $key );
-}
-
-sub clear
-{
-    my ($self) = @_;
-    return $self->base_strategy->clear;
+    my ($self,$rec) = @_;
+    get_logger()->debug( "set_cache_record " . $rec->name );
+    return $self->base_strategy->set_cache_record( $rec );    
 }
 
 sub _build_base_strategy
@@ -116,7 +93,7 @@ around BUILDARGS => sub
             get_logger()->debug( "base strategy node found" );
             $args{base_strategy} = Autocache->singleton->get_strategy( $node->value );
         }
-
+        
         return $class->$orig( %args );
     }
     else
