@@ -2,7 +2,9 @@ package Autocache::WorkQueue;
 
 use Any::Moose;
 
-use Autocache::Logger qw(get_logger);
+use Log::Log4perl qw( get_logger );
+#use Functions::Log qw( get_logger );
+use Data::Dumper;
 
 #
 # Null Memory Strategy - never expire, in memory cache
@@ -11,7 +13,7 @@ use Autocache::Logger qw(get_logger);
 has '_queue' => (
     is => 'rw',
     default => sub { [] },
-    init_arg => undef,
+    init_arg => undef,    
 );
 
 #
